@@ -13,8 +13,8 @@
 G_BEGIN_DECLS
 
 #define SOUP_MAJOR_VERSION (2)
-#define SOUP_MINOR_VERSION (46)
-#define SOUP_MICRO_VERSION (0)
+#define SOUP_MINOR_VERSION (52)
+#define SOUP_MICRO_VERSION (2)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
     (SOUP_MAJOR_VERSION > (major) || \
@@ -48,6 +48,9 @@ gboolean soup_check_version     (guint major,
 #define SOUP_VERSION_2_42 (SOUP_ENCODE_VERSION (2, 42))
 #define SOUP_VERSION_2_44 (SOUP_ENCODE_VERSION (2, 44))
 #define SOUP_VERSION_2_46 (SOUP_ENCODE_VERSION (2, 46))
+#define SOUP_VERSION_2_48 (SOUP_ENCODE_VERSION (2, 48))
+#define SOUP_VERSION_2_50 (SOUP_ENCODE_VERSION (2, 50))
+#define SOUP_VERSION_2_52 (SOUP_ENCODE_VERSION (2, 52))
 
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
@@ -256,6 +259,48 @@ gboolean soup_check_version     (guint major,
 # define SOUP_AVAILABLE_IN_2_46
 #endif
 
+#if SOUP_VERSION_MIN_REQUIRED >= SOUP_VERSION_2_48
+# define SOUP_DEPRECATED_IN_2_48                GLIB_DEPRECATED
+# define SOUP_DEPRECATED_IN_2_48_FOR(f)         GLIB_DEPRECATED_FOR(f)
+#else
+# define SOUP_DEPRECATED_IN_2_48
+# define SOUP_DEPRECATED_IN_2_48_FOR(f)
+#endif
+
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_2_48
+# define SOUP_AVAILABLE_IN_2_48                 GLIB_UNAVAILABLE(2, 48)
+#else
+# define SOUP_AVAILABLE_IN_2_48
+#endif
+
+#if SOUP_VERSION_MIN_REQUIRED >= SOUP_VERSION_2_50
+# define SOUP_DEPRECATED_IN_2_50                GLIB_DEPRECATED
+# define SOUP_DEPRECATED_IN_2_50_FOR(f)         GLIB_DEPRECATED_FOR(f)
+#else
+# define SOUP_DEPRECATED_IN_2_50
+# define SOUP_DEPRECATED_IN_2_50_FOR(f)
+#endif
+
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_2_50
+# define SOUP_AVAILABLE_IN_2_50                 GLIB_UNAVAILABLE(2, 50)
+#else
+# define SOUP_AVAILABLE_IN_2_50
+#endif
+
+#if SOUP_VERSION_MIN_REQUIRED >= SOUP_VERSION_2_52
+# define SOUP_DEPRECATED_IN_2_52                GLIB_DEPRECATED
+# define SOUP_DEPRECATED_IN_2_52_FOR(f)         GLIB_DEPRECATED_FOR(f)
+#else
+# define SOUP_DEPRECATED_IN_2_52
+# define SOUP_DEPRECATED_IN_2_52_FOR(f)
+#endif
+
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_2_52
+# define SOUP_AVAILABLE_IN_2_52                 GLIB_UNAVAILABLE(2, 52)
+#else
+# define SOUP_AVAILABLE_IN_2_52
+#endif
+
 G_END_DECLS
 
 #endif /* SOUP_VERSION_H */
